# python-imbalance

Python helper package for accessing the datalakes and other services 
for the solution.

This package is to be copied into ~/.local/lib/python3.8/site-packages/
Copying is done using the deploy.sh script

